@@ -10,7 +10,7 @@ end
 
 # On CI we publish coverage to codecov.io
 # To use the codecov action, we need to generate XML based coverage report
-if ENV["CI"] == "true"
+if ENV.fetch("CI", nil) == "true"
   begin
     require "simplecov-cobertura"
     SimpleCov.formatter = SimpleCov::Formatter::CoberturaFormatter
@@ -21,7 +21,7 @@ end
 
 # Due to circular dependency (SimpleCov depends on Docile), remove docile and
 # then require the docile gem again below.
-Object.send(:remove_const, :Docile)
+Object.send(:remove_const, :Docile) # rubocop:disable RSpec/RemoveConst
 $LOADED_FEATURES.reject! { |f| f.include?("/lib/docile") }
 
 # Require Docile again, now with coverage enabled
